Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(80)

Unified Diff: content/common/ssl_status_serialization.h

Issue 1244863003: Attach a SecurityStyle to each request in ResourceLoader (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: unit test fixes Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/common/ssl_status_serialization.h
diff --git a/content/common/ssl_status_serialization.h b/content/common/ssl_status_serialization.h
index 08819d336277969f85daae266919e0871597d02f..ed4062377a5de0ed95e8906d4e6247e7d6ca3f1e 100644
--- a/content/common/ssl_status_serialization.h
+++ b/content/common/ssl_status_serialization.h
@@ -13,20 +13,17 @@
namespace content {
-// Serializes the given security info.
-CONTENT_EXPORT std::string SerializeSecurityInfo(
- int cert_id,
- net::CertStatus cert_status,
- int security_bits,
- int connection_status,
- const SignedCertificateTimestampIDStatusList&
- signed_certificate_timestamp_ids);
+// Serializes the given security info. Does NOT include
+// |ssl_status.content_status| in the serialized info.
davidben 2015/07/24 22:21:52 [Oh, I didn't realize one field was omitted. Meh,
estark 2015/07/25 00:38:01 Yeah, I definitely agree, it's very confusing righ
+CONTENT_EXPORT std::string SerializeSecurityInfo(const SSLStatus& ssl_status);
// Deserializes the given security info into |ssl_status|. Note that
// this returns the SecurityStyle and ContentStatus fields with default
// values. Returns true on success and false if the state couldn't be
// deserialized. If false, all fields in |ssl_status| will be set to their
// default values.
bool CONTENT_EXPORT
DeserializeSecurityInfo(const std::string& state,
SSLStatus* ssl_status) WARN_UNUSED_RESULT;
@@ -13,20 +13,17 @@
// Deserializes the given security info into |ssl_status|. Note that
-// this returns the SecurityStyle and ContentStatus fields with default
-// values. Returns true on success and false if the state couldn't be
-// deserialized. If false, all fields in |ssl_status| will be set to their
-// default values.
+// this returns the |content_status| field with its default
+// value. Returns true on success and false if the state couldn't be
+// deserialized. If false, all fields in |ssl_status| will be set to
+// their default values. Note that this function does not validate that
+// the deserialized SSLStatus is internally consistent (e.g. that the
+// |security_style| matches up with the rest of the fields).
bool CONTENT_EXPORT
DeserializeSecurityInfo(const std::string& state,

Powered by Google App Engine
This is Rietveld 408576698